@@ -7,6 +7,7 @@ import JinjaStaticRenderer as renderer
 import Reader as Reader
 import Core as Core
 import Extensions as Extensions
+import inspect
 
 class Wrangler():
 
@@ -27,7 +28,27 @@ class Wrangler():
             "force": "false",
             "nocache": "false",
             "item_class": "Page",
-            "views": None
+            "lib_path": "site/lib",
+            "extensions": {
+                "SiteMap": {
+                    "options": {
+                        "webroot":"/"
+                    }
+                },
+                "CacheBuster": {
+                    "options": {}
+                },
+                "FileInfo": {
+                    "options": {
+                        "directory": "www/assets",
+                        "filetypes": ["css", "pdf"],
+                        "webroot": "www"
+                    }
+                },
+                "MooExtension": {
+                    "options": {}
+                }
+            }
         },
         "site_vars": {
             "paths": {
@@ -79,14 +100,17 @@ class Wrangler():
         if (args.__dict__["config"] != None):
             self.config['config_path'] = args.__dict__["config"]
 
+
+        self.config.update( self.defaults["generator_config"] )
+
         if os.path.exists( self.config['config_path'] ):
             userConfig = json.load( file(self.config['config_path']) )
             self.config.update( userConfig["generator_config"] )
-        else: 
-            userConfig = self.defaults
+        # else: 
+            # userConfig = self.defaults
 
         # Apply settings from the config file (if present)
-        self.config.update( userConfig["generator_config"] )
+        # self.config.update( userConfig["generator_config"] )
 
         # Apply command line flags if set, ignore Nones.
         self.config.update((k, v) for k, v in args.__dict__.iteritems() if v is not None)
@@ -101,8 +125,8 @@ class Wrangler():
 
         self.update_config(args)
 
-        if "views" in self.config:
-            self.load_classes(self.config["views"])
+        if "lib_path" in self.config:
+            self.load_classes(self.config["lib_path"])
 
         self._reporter = Core.Reporter(self.config)
         self._reader = Reader.Reader(self.config)
@@ -113,7 +137,6 @@ class Wrangler():
         self.graph = self._reader.fetch()
 
 
-
         # Set output paths before trying to render anything.
         # Two loops not so efficient... hmmm
         def set_output(node):
@@ -132,7 +155,8 @@ class Wrangler():
             hook = sys.modules["WranglerHooks"].BeforeRender(self.config, self._renderer)
             hook.process(self.graph)
 
-        self.config["site_vars"]["sitemap"] = Extensions.SiteMap().build(self.graph.tree())
+        self.process_extensions()
+    
 
         rendered = 0
 
@@ -158,12 +182,11 @@ class Wrangler():
                         
                         cargo.set_related_nodes(related)
 
-
                     if self._writer.save(self._renderer.render(cargo)):
                         rendered += 1
 
-                cargo.cleanup()
-                del cargo
+                    cargo.cleanup()
+                    del cargo
     
 
         if "WranglerHooks" in sys.modules and hasattr(sys.modules["WranglerHooks"], "AfterRender"):
@@ -186,6 +209,7 @@ class Wrangler():
 
         moduleNames = []
 
+
         for f in classfiles:
             moduleNames.append(os.path.basename(f.replace(".py", "")))
 
@@ -197,6 +221,27 @@ class Wrangler():
                 sys.path[:] = path 
 
 
+    def process_extensions(self):
+        """
+        Load extensions from the core and import any from the site/lib directory too
+        """
+        extension_classes = inspect.getmembers(sys.modules["wrangler.Extensions"], inspect.isclass)
+
+        if "lib_path" in self.config:
+            extension_classes = extension_classes + inspect.getmembers(sys.modules["Extensions"], inspect.isclass)
+
+        if extension_classes:
+            for extension_name, extension_config in self.config["extensions"].items():
+                # try:
+                    ext = [(name, obj) for (name, obj) in extension_classes if name == extension_name]
+                    if ext[0]:
+                        extension = ext[0][1](extension_config, self.graph)
+                        self._reporter.verbose("Running extension %s > site.%s" % (ext[0][0], ext[0][0].lower()))
+                        self.config["site_vars"][extension_name.lower()] = extension.run()
+                # except:
+                    # self._reporter.log("Couldn't load extension %s" % (extension_name), "red")
+
+
 def start():
     sys.exit(Wrangler().main())
 
